@@ -3,7 +3,7 @@ Binary Protocol API
 A lightweight binary protocol implementation for efficient client-server communication.
 """
 
-from .protocol.config import ProtocolConfig
+from .protocol.config import ProtocolConfig, TransportType
 from .protocol.exceptions import (
     ProtocolError,
     MessageValidationError,
@@ -15,9 +15,10 @@ from .protocol.exceptions import (
 from .client import BinaryClient
 from .server import BinaryServer
 
-__version__ = "0.1.0"
+__version__ = "0.2.1"
 __all__ = [
     'ProtocolConfig',
+    'TransportType',
     'BinaryClient',
     'BinaryServer',
     'ProtocolError',
